@@ -29,10 +29,16 @@
 /* 
  */
 
+/* These have different values from xcircuit.h, so undefine them for ASG */
+#undef RIGHT
+#undef TOP
+
 #define LEFT 0
 #define TOP 1		/* Used to define the desired side in neighbor finding */
+#define UP 1
 #define RIGHT 2
 #define BOTTOM 3
+#define DOWN 3
 
 #define FURTHER 2
 #define CLOSER -2
