@@ -485,7 +485,7 @@ extern int *my_free(p)
     int *p; 
 {
     int q = 1;		/* NOP */
-    cfree(p);
+    free(p);
     return(NULL);
 }
 /* ------------------------------------------------------------------------
@@ -495,20 +495,23 @@ extern int *my_free(p)
 list *free_list(l)
     list *l;
 {
-    list *ll;
+    list *ll, *trash;
     int i;
     char *cptr;
 
-    for(ll = l; ll != NULL; ll = ll->next)
+    for(ll = l; ll != NULL;)
     {
-	l = ll;
-	my_free(l);
-	/* Explicitly wipe memory */
-	cptr = (char *)l;
+	trash = ll;
+	ll = ll->next;
+
+	/* Explicitly wipe memory */		/* ??? */
+	cptr = (char *)trash;
 	for (i = 0; i < sizeof(list); i++)
 	{
 	    *(cptr + i) = 0;
 	}
+
+	my_free(trash);
     }
     return(NULL);
 }
@@ -1054,12 +1057,13 @@ ilist *append_ilist(l1,l2)
 ilist *free_ilist(l)
     ilist *l;
 {
-    ilist *ll;
+    ilist *ll, *trash;
     
-    for(ll = l; ll != NULL; ll = ll->next)
+    for(ll = l; ll != NULL;)
     {
-	l = ll;
-	my_free(l);
+	trash = ll;
+	ll = ll->next;
+	my_free(trash);
     }
     return(NULL);
 }
