@@ -233,10 +233,15 @@ void crashrecover()
    if (xobjs.tempfile != NULL) {
       unlink(xobjs.tempfile);
       free(xobjs.tempfile);
+      xobjs.tempfile = NULL;
+   }
+   if (strlen(_STR2) == 0) {
+      Wprintf("Error: No temp file name for crash recovery!");
+   }
+   else {
+      xobjs.tempfile = strdup(_STR2);
+      startloadfile(-1);
    }
-   xobjs.tempfile = strdup(_STR2);
-
-   startloadfile(-1);
 }
 
 /*----------------------------------------------------------------------*/
@@ -402,8 +407,6 @@ void listfiles(xcWidget w, popupstruct *okaystruct, caddr_t calldata)
 
       /* get list of files in the current directory (cwd) */
 
-      if (files == NULL) 
-         files = (fileliststruct *) malloc (INITDIRS * sizeof(fileliststruct));
       flfiles = 0;
       if (cwdname == NULL) {
 	 cwdname = (char *) malloc (sizeof(char));
@@ -426,6 +429,8 @@ void listfiles(xcWidget w, popupstruct *okaystruct, caddr_t calldata)
 	 return;
       }
       else {
+	 if (files == NULL) 
+	    files = (fileliststruct *) malloc (INITDIRS * sizeof(fileliststruct));
 
 	 /* write the contents of the current directory into the   */
 	 /* array "filenames[]" (except for current directory ".") */
