@@ -48,7 +48,7 @@ extern XCWindowData *areawin;
 extern const char *utf8encodings[][256];
 #endif
 
-extern float version;
+extern char version[];
 
 #ifdef TCL_WRAPPER
 extern Tcl_Interp *xcinterp;
@@ -162,12 +162,14 @@ int loadfontfile(char *fname)
    float fontscale = 1.0;
    objectptr *j, *eptr;
    objectptr *encoding = NULL;
-   float saveversion = version;
+   char saveversion[20];
    char *fontname = strdup(fname);
 #ifdef HAVE_CAIRO
    const char **utf8enc = NULL;
 #endif /* HAVE_CAIRO */
 
+   strcpy(saveversion, version);
+
    /* check to see if font name is in list of fonts */
 
    for (i = 0; i < fontcount; i++) {
@@ -212,10 +214,10 @@ int loadfontfile(char *fname)
 	 /* since we can be in the middle of a file load, protect the	*/
 	 /* current version number for the file load.			*/
 
-	 version = PROG_VERSION;
+         strcpy(version, PROG_VERSION);
 	 if (loadlibrary(FONTLIB) == FALSE) {
 	 };
-	 version = saveversion;
+         strcpy(version, saveversion);
       }
 
       else if (!strcmp(cmdptr, "family:")){
@@ -355,6 +357,9 @@ int loadfontfile(char *fname)
 	 }
 	 /* i == 6 maps to ISO8859-5 */
 	 if (strstr(tempname, "8859-5") != NULL) {
+#ifndef TCL_WRAPPER
+	    char estr[12];
+#endif
 	    flags |= ((6 + 2) << 7);
 #ifdef TCL_WRAPPER
 	    XcInternalTagCall(xcinterp, 3, "label", "encoding", "ISO8859-5");
