@@ -156,6 +156,7 @@ void printhelppix()
     { XCF_Text_Up,	"Move up one line"},
     { XCF_Text_Down,	"Move down one line"},
     { XCF_Text_Delete,	"Delete character(s)"},
+    { XCF_Text_Delete_Param,	"Delete parameter from text"},
     { XCF_Text_Return,	"End text edit"},
     { XCF_Text_Split,	"Split label at cursor"},
     { XCF_SPACER,	NULL},
@@ -329,9 +330,6 @@ void starthelp(xcWidget button, caddr_t clientdata, caddr_t calldata)
    XtTranslateCoords(areawin->area, (Position) (areawidth + 10), -50,
 	&xpos, &ypos);
 
-   /*  Always direct the call to the main menu button. */
-   button = OptionsHelpButton;
-
    savebutton = getgeneric(button, starthelp, NULL);
 
    /* Generate the pixmap and write the help text to it */
