@@ -1088,11 +1088,11 @@ static PyObject *xc_getattr(PyObject *self, PyObject *args)
 	 PyDict_SetItem(rdict, PyString_FromString("position"), 
 		make_pair(&(TOLABEL(gelem)->position)));
 	 PyDict_SetItem(rdict, PyString_FromString("rotation"),
-		PyInt_FromLong((long)TOLABEL(gelem)->rotation));
+		PyFloat_FromDouble((double)TOLABEL(gelem)->rotation));
 	 PyDict_SetItem(rdict, PyString_FromString("scale"),
 		PyFloat_FromDouble((double)TOLABEL(gelem)->scale));
-	 PyDict_SetItem(rdict, PyString_FromString("justify"),
-		PyInt_FromLong((long)TOLABEL(gelem)->justify));
+	 PyDict_SetItem(rdict, PyString_FromString("anchor"),
+		PyInt_FromLong((long)TOLABEL(gelem)->anchor));
 	 PyDict_SetItem(rdict, PyString_FromString("pin"),
 		PyInt_FromLong((long)TOLABEL(gelem)->pin));
 	 lstr = PyGetStringParts(TOLABEL(gelem)->string);
@@ -1153,7 +1153,7 @@ static PyObject *xc_getattr(PyObject *self, PyObject *args)
 	 PyDict_SetItem(rdict, PyString_FromString("position"), 
 		make_pair(&(TOOBJINST(gelem)->position)));
 	 PyDict_SetItem(rdict, PyString_FromString("rotation"),
-		PyInt_FromLong((long)TOOBJINST(gelem)->rotation));
+		PyFloat_FromDouble((double)TOOBJINST(gelem)->rotation));
 	 PyDict_SetItem(rdict, PyString_FromString("scale"),
 		PyFloat_FromDouble((double)TOOBJINST(gelem)->scale));
 	 PyDict_SetItem(rdict, PyString_FromString("name"),
@@ -1327,8 +1327,8 @@ static PyObject *xc_setattr(PyObject *self, PyObject *args)
 
    switch(ELEMENTTYPE(*gelem)) {
       case LABEL:
-	 if ((dval = PyDict_GetItemString(attrdict, "justify")) != NULL) {
-	    TOLABEL(gelem)->justify = PyInt_AsLong(dval);
+	 if ((dval = PyDict_GetItemString(attrdict, "anchor")) != NULL) {
+	    TOLABEL(gelem)->anchor = PyInt_AsLong(dval);
 	 }
 	 if ((dval = PyDict_GetItemString(attrdict, "string")) != NULL) {
 	    freelabel(TOLABEL(gelem)->string);
@@ -1960,7 +1960,7 @@ void init_interpreter()
    PyRun_SimpleString("keydict = {}\n");	/* initialize key/function pairs */
    PyRun_SimpleString("buttondict = {}\n");  /* initialize button/function pairs */
    PyRun_SimpleString("tooldict = {}\n");  /* initialize tool/function pairs */
-   sprintf(_STR, "xc_version = %2.1f\n", PROG_VERSION);
+   sprintf(_STR, "xc_version = %s\n", PROG_VERSION);
    PyRun_SimpleString(_STR);
 }
 
