@@ -52,7 +52,6 @@ extern short fontcount;
 extern XCWindowData *areawin;
 extern Globaldata xobjs;
 extern short beeper;
-extern int *appcolors;
 extern Widget menuwidgets[];
 extern Display *dpy;
 
@@ -415,13 +414,13 @@ short readcommand(short mode, FILE *fd)
 void defaultscript()
 {
    FILE *fd;
-   char *tmp_s = getenv((const char *)"XCIRCUIT_LIB_DIR");
+   char *tmp_s = getenv((const char *)"XCIRCUIT_SRC_DIR");
 
-   if (!tmp_s) tmp_s = BUILTINS_DIR;
+   if (!tmp_s) tmp_s = SCRIPTS_DIR;
    sprintf(_STR2, "%s/%s", tmp_s, STARTUP_FILE);
 
    if ((fd = fopen(_STR2, "r")) == NULL) {
-      sprintf(_STR2, "%s/%s", BUILTINS_DIR, STARTUP_FILE);
+      sprintf(_STR2, "%s/%s", SCRIPTS_DIR, STARTUP_FILE);
       if ((fd = fopen(_STR2, "r")) == NULL) {
          Wprintf("Failed to open startup script \"%s\"\n", STARTUP_FILE);
 	 return;
@@ -508,6 +507,7 @@ void loadrcfile()
    addnewcolorentry(xc_getlayoutcolor(INFOLABELCOLOR));
    addnewcolorentry(xc_getlayoutcolor(RATSNESTCOLOR));
    addnewcolorentry(xc_getlayoutcolor(BBOXCOLOR));
+   addnewcolorentry(xc_getlayoutcolor(FIXEDBBOXCOLOR));
 
 
    /* Add the default key bindings */
