@@ -563,7 +563,7 @@ void SVGDrawString(labelptr drawlabel, int passcolor, objinstptr localinst)
    char *symbol_html_encoding[] = {
 	" ", "!", "&#8704;", "#", "&#8707;", "%", "&", "?", "(", ")",
 	"*", "+", ",", "&#8722;", ".", "/", "0", "1", "2", "3", "4",
-	"5", "6", "7", "8", "9", ":", ";", "<", "=", ">", "?", "&#8773;",
+	"5", "6", "7", "8", "9", ":", ";", "&lt;", "=", "&gt;", "?", "&#8773;",
 	"&#913;", "&#914;", "&#935;", "&#916;", "&#917;", "&#934;",
 	"&#915;", "&#919;", "&#921;", "&#977;", "&#922;", "&#923;",
 	"&#924;", "&#925;", "&#927;", "&#928;", "&#920;", "&#929;",
