@@ -86,6 +86,11 @@ typedef struct {
    float scale;			/* old scale value */
 } scaleinfo;
 
+typedef struct {
+   XPoint rotpos;		/* original position */
+   float rotation;		/* old rotation value */
+} rotateinfo;
+
 u_char undo_collect = (u_char)0;
 
 /*----------------------------------------------------------------------*/
@@ -418,7 +423,8 @@ void undelete_one_element(objinstptr thisinst, genericptr thiselem)
 void register_for_undo(u_int type, u_char mode, objinstptr thisinst, ...)
 {
    va_list args;
-   int drawmode, nval, oval, *idata, snum, deltax, deltay, dir, i;
+   int drawmode, nval, oval, *idata, snum, deltax, deltay, i;
+   double dir;
    short *slist;
    objectptr delobj;
    objinstptr newinst;
@@ -541,7 +547,7 @@ void register_for_undo(u_int type, u_char mode, objinstptr thisinst, ...)
 	       erec->save.string =
 			stringcopyall(((labelptr)egen)->string,
 			areawin->topinstance);
-	       newrecord->idata = ((labelptr)egen)->justify;
+	       newrecord->idata = ((labelptr)egen)->anchor;
 	       break;
 	    case POLYGON:
 	       newrecord->idata = ((polyptr)egen)->number;
@@ -589,7 +595,7 @@ void register_for_undo(u_int type, u_char mode, objinstptr thisinst, ...)
 	 break;
 
       case XCF_ChangeStyle:
-      case XCF_Justify:
+      case XCF_Anchor:
       case XCF_Color:
 	 /* 2 args:							*/
 	 /*	egen = element that was changed (with new value)	*/
@@ -627,13 +633,13 @@ void register_for_undo(u_int type, u_char mode, objinstptr thisinst, ...)
       case XCF_Rotate:
 	 /* 2 args:							*/
 	 /*	fpoint = point of flip (XPoint *)			*/
-	 /*	dir = direction and amound of rotation (int)		*/
+	 /*	dir = direction and amount of rotation (float)		*/
 	 fpoint = va_arg(args, XPoint *);
-	 dir = va_arg(args, int);
-	 newrecord->undodata = (char *)malloc(sizeof(XPoint));
-	 ((XPoint *)newrecord->undodata)->x = fpoint->x;
-	 ((XPoint *)newrecord->undodata)->y = fpoint->y;
-	 newrecord->idata = dir;
+	 dir = va_arg(args, double);
+	 newrecord->undodata = (char *)malloc(sizeof(rotateinfo));
+	 ((rotateinfo *)newrecord->undodata)->rotpos.x = fpoint->x;
+	 ((rotateinfo *)newrecord->undodata)->rotpos.y = fpoint->y;
+	 ((rotateinfo *)newrecord->undodata)->rotation = (float)dir;
 	 break;
 
       case XCF_Move:
@@ -773,11 +779,11 @@ short undo_one_action()
 	 newpage(thisrecord->idata);
 	 break;
 
-      case XCF_Justify:
+      case XCF_Anchor:
 	 thislabel = (labelptr)(thisrecord->undodata);
 	 snum = thisrecord->idata;
-	 thisrecord->idata = thislabel->justify;
-	 thislabel->justify = snum;
+	 thisrecord->idata = thislabel->anchor;
+	 thislabel->anchor = snum;
 	 areawin->redraw_needed = True;
 	 drawarea(areawin->area, NULL, NULL);
 	 break;
@@ -818,16 +824,16 @@ short undo_one_action()
 	 switch (erec->element->type) {
 	    case LABEL: {
 	       stringpart *tmpstr;
-	       int tmpjust;
+	       int tmpanchor;
 	       labelptr elab = (labelptr)(erec->element);
 	       undrawtext(elab);
 	       tmpstr = elab->string;
-	       tmpjust = (int)elab->justify;
+	       tmpanchor = (int)elab->anchor;
 	       elab->string = stringcopyback(erec->save.string,
 				thisrecord->thisinst);
-	       elab->justify = (short)thisrecord->idata;
+	       elab->anchor = (short)thisrecord->idata;
 	       erec->save.string = tmpstr;
-	       thisrecord->idata = tmpjust;
+	       thisrecord->idata = tmpanchor;
 	       resolveparams(thisrecord->thisinst);
 	       redrawtext(elab);
 	    } break;
@@ -1063,8 +1069,8 @@ short undo_one_action()
 	 break;
 
       case XCF_Rotate:
-	 position = *((XPoint *)thisrecord->undodata);
-	 elementrotate(-thisrecord->idata, &position);
+	 position = ((rotateinfo *)thisrecord->undodata)->rotpos;
+	 elementrotate(-((rotateinfo *)thisrecord->undodata)->rotation, &position);
 	 break;
 
       case XCF_Move:
@@ -1213,11 +1219,11 @@ short redo_one_action()
 	 newpage(*((int *)thisrecord->undodata));
 	 break;
 
-      case XCF_Justify:
+      case XCF_Anchor:
 	 thislabel = (labelptr)(thisrecord->undodata);
 	 snum = thisrecord->idata;
-	 thisrecord->idata = thislabel->justify;
-	 thislabel->justify = snum;
+	 thisrecord->idata = thislabel->anchor;
+	 thislabel->anchor = snum;
 	 areawin->redraw_needed = True;
 	 drawarea(areawin->area, NULL, NULL);
 	 break;
@@ -1277,16 +1283,16 @@ short redo_one_action()
 	 switch (erec->element->type) {
 	    case LABEL: {
 	       stringpart *tmpstr;
-	       int tmpjust;
+	       int tmpanchor;
 	       labelptr elab = (labelptr)(erec->element);
 	       undrawtext(elab);
 	       tmpstr = elab->string;
-	       tmpjust = (int)elab->justify;
+	       tmpanchor = (int)elab->anchor;
 	       elab->string = stringcopyback(erec->save.string,
 				thisrecord->thisinst);
-	       elab->justify = (short)thisrecord->idata;
+	       elab->anchor = (short)thisrecord->idata;
 	       erec->save.string = tmpstr;
-	       thisrecord->idata = tmpjust;
+	       thisrecord->idata = tmpanchor;
 	       resolveparams(thisrecord->thisinst);
 	       redrawtext(elab);
 	    } break;
@@ -1497,8 +1503,8 @@ short redo_one_action()
 	 break;
 
       case XCF_Rotate:
-	 position = *((XPoint *)thisrecord->undodata);
-	 elementrotate(thisrecord->idata, &position);
+	 position = ((rotateinfo *)thisrecord->undodata)->rotpos;
+	 elementrotate(((rotateinfo *)thisrecord->undodata)->rotation, &position);
 	 break;
 
       case XCF_Move:
@@ -1654,13 +1660,13 @@ void free_undo_data(Undoptr thisrecord, u_char mode)
 	 }
 	 else { /* MODE_REDO */
 	    uobj = (objectptr)thisrecord->undodata;
-	    reset(uobj, DESTROY);
+	    if (uobj) reset(uobj, DESTROY);
 	 }
 	 break;
 
       case XCF_Push:
       case XCF_ChangeStyle:
-      case XCF_Justify:
+      case XCF_Anchor:
       case XCF_Color:
 	 /* Do nothing --- undodata points to a valid element */
 	 break;
