@@ -6,6 +6,7 @@
 /* written (ie. converted the tables) by Erik van der Wal, May 2014  	   */
 /*-------------------------------------------------------------------------*/
 
+#include <stdio.h>
 
 /*-------------------------------------------------------------------------*/
 /* The data in this file is based on a number of files from unicode.org    */
@@ -26,17 +27,16 @@
 #	days of receipt.
 #
 #	Unicode, Inc. hereby grants the right to freely use the information
-                                                 --------------------------
+#                                                --------------------------
 #	supplied in this file in the creation of products supporting the
 #	Unicode Standard, and to make copies of this file in any form for
 #	internal or external distribution as long as this notice remains
-                                          ------------------------------       
+#                                         ------------------------------
 #	attached.
-        --------
+#       --------
 */
 
 
-
 /* Since the character at index 0 can never be used, it is used to store   */
 /* the identification of the given encoding                                */
 /* The encoding can be placed in random order, as long as it does start    */
@@ -407,8 +407,9 @@ const char *utf8encodings[][256] = {
 /* 0xfc */ "\xc3\xbc",     "\xc5\xa9",     "\xc5\xab",     "\xcb\x99"
 },
 /*--------------------------------------------------------------------------*/
-/* iso 8859-5                                                               */
-/* based on: ftp://ftp.unicode.org/Public/MAPPINGS/ISO8859/8859-5.TXT       */
+/* CP1254 (ISO Latin-5)                                                     */
+/* based on:								    */
+/* ftp://ftp.unicode.org/Public/MAPPINGS/VENDORS/MICSFT/WINDOWS/CP1254.TXT  */
 /*--------------------------------------------------------------------------*/
 {
 /* 0x00 */ "ISOLatin5",    REPLC_CHAR,     REPLC_CHAR,     REPLC_CHAR,
@@ -431,38 +432,38 @@ const char *utf8encodings[][256] = {
 /* 0x68 */ "h",    "i",    "j",    "k",    "l",    "m",    "n",    "o",
 /* 0x70 */ "p",    "q",    "r",    "s",    "t",    "u",    "v",    "w",
 /* 0x78 */ "x",    "y",    "z",    "{",    "|",    "}",    "~",    "\x7f",
-/* 0x80 */ "\xc2\x80",     "\xc2\x81",     "\xc2\x82",     "\xc2\x83",
-/* 0x84 */ "\xc2\x84",     "\xc2\x85",     "\xc2\x86",     "\xc2\x87",
-/* 0x88 */ "\xc2\x88",     "\xc2\x89",     "\xc2\x8a",     "\xc2\x8b",
-/* 0x8c */ "\xc2\x8c",     "\xc2\x8d",     "\xc2\x8e",     "\xc2\x8f",
-/* 0x90 */ "\xc2\x90",     "\xc2\x91",     "\xc2\x92",     "\xc2\x93",
-/* 0x94 */ "\xc2\x94",     "\xc2\x95",     "\xc2\x96",     "\xc2\x97",
-/* 0x98 */ "\xc2\x98",     "\xc2\x99",     "\xc2\x9a",     "\xc2\x9b",
-/* 0x9c */ "\xc2\x9c",     "\xc2\x9d",     "\xc2\x9e",     "\xc2\x9f",
-/* 0xa0 */ "\xc2\xa0",     "\xd0\x81",     "\xd0\x82",     "\xd0\x83",
-/* 0xa4 */ "\xd0\x84",     "\xd0\x85",     "\xd0\x86",     "\xd0\x87",
-/* 0xa8 */ "\xd0\x88",     "\xd0\x89",     "\xd0\x8a",     "\xd0\x8b",
-/* 0xac */ "\xd0\x8c",     "\xc2\xad",     "\xd0\x8e",     "\xd0\x8f",
-/* 0xb0 */ "\xd0\x90",     "\xd0\x91",     "\xd0\x92",     "\xd0\x93",
-/* 0xb4 */ "\xd0\x94",     "\xd0\x95",     "\xd0\x96",     "\xd0\x97",
-/* 0xb8 */ "\xd0\x98",     "\xd0\x99",     "\xd0\x9a",     "\xd0\x9b",
-/* 0xbc */ "\xd0\x9c",     "\xd0\x9d",     "\xd0\x9e",     "\xd0\x9f",
-/* 0xc0 */ "\xd0\xa0",     "\xd0\xa1",     "\xd0\xa2",     "\xd0\xa3",
-/* 0xc4 */ "\xd0\xa4",     "\xd0\xa5",     "\xd0\xa6",     "\xd0\xa7",
-/* 0xc8 */ "\xd0\xa8",     "\xd0\xa9",     "\xd0\xaa",     "\xd0\xab",
-/* 0xcc */ "\xd0\xac",     "\xd0\xad",     "\xd0\xae",     "\xd0\xaf",
-/* 0xd0 */ "\xd0\xb0",     "\xd0\xb1",     "\xd0\xb2",     "\xd0\xb3",
-/* 0xd4 */ "\xd0\xb4",     "\xd0\xb5",     "\xd0\xb6",     "\xd0\xb7",
-/* 0xd8 */ "\xd0\xb8",     "\xd0\xb9",     "\xd0\xba",     "\xd0\xbb",
-/* 0xdc */ "\xd0\xbc",     "\xd0\xbd",     "\xd0\xbe",     "\xd0\xbf",
-/* 0xe0 */ "\xd1\x80",     "\xd1\x81",     "\xd1\x82",     "\xd1\x83",
-/* 0xe4 */ "\xd1\x84",     "\xd1\x85",     "\xd1\x86",     "\xd1\x87",
-/* 0xe8 */ "\xd1\x88",     "\xd1\x89",     "\xd1\x8a",     "\xd1\x8b",
-/* 0xec */ "\xd1\x8c",     "\xd1\x8d",     "\xd1\x8e",     "\xd1\x8f",
-/* 0xf0 */ "\xe2\x84\x96", "\xd1\x91",     "\xd1\x92",     "\xd1\x93",
-/* 0xf4 */ "\xd1\x94",     "\xd1\x95",     "\xd1\x96",     "\xd1\x97",
-/* 0xf8 */ "\xd1\x98",     "\xd1\x99",     "\xd1\x9a",     "\xd1\x9b",
-/* 0xfc */ "\xd1\x9c",     "\xc2\xa7",     "\xd1\x9e",     "\xd1\x9f"
+/* 0x80 */ "\xe2\x82\xac", REPLC_CHAR,     "\xe2\x80\x9a", "\xc6\x92",
+/* 0x84 */ "\xe2\x80\x9e", "\xe2\x80\xa6", "\xe2\x80\xa0", "\xe2\x80\xa1",
+/* 0x88 */ "\xcb\x86",     "\xe2\x80\xb0", "\xc5\xa0",     "\xe2\x80\xb9",
+/* 0x8c */ "\xc5\x92",     REPLC_CHAR,     REPLC_CHAR,     REPLC_CHAR,
+/* 0x90 */ REPLC_CHAR,     "\xe2\x80\x98", "\xe2\x80\x99", "\xe2\x80\x9c",
+/* 0x94 */ "\xe2\x80\x9d", "\xe2\x80\xa2", "\xe2\x80\x93", "\xe2\x80\x94",
+/* 0x98 */ "\xcb\x9c",     "\xe2\x84\xa2", "\xc5\xa1",     "\xe2\x80\xba",
+/* 0x9c */ "\xc5\x93", REPLC_CHAR, REPLC_CHAR, "\xc5\xb8",
+/* 0xa0 */ "\xc2\xa0", "\xc2\xa1", "\xc2\xa2", "\xc2\xa3",
+/* 0xa4 */ "\xc2\xa4", "\xc2\xa5", "\xc2\xa6", "\xc2\xa7",
+/* 0xa8 */ "\xc2\xa8", "\xc2\xa9", "\xc2\xaa", "\xc2\xab",
+/* 0xac */ "\xc2\xac", "\xc2\xad", "\xc2\xae", "\xc2\xaf",
+/* 0xb0 */ "\xc2\xb0", "\xc2\xb1", "\xc2\xb2", "\xc2\xb3",
+/* 0xb4 */ "\xc2\xb4", "\xc2\xb5", "\xc2\xb6", "\xc2\xb7",
+/* 0xb8 */ "\xc2\xb8", "\xc2\xb9", "\xc2\xba", "\xc2\xbb",
+/* 0xbc */ "\xc2\xbc", "\xc2\xbd", "\xc2\xbe", "\xc2\xbf",
+/* 0xc0 */ "\xc3\x80", "\xc3\x81", "\xc3\x82", "\xc3\x83",
+/* 0xc4 */ "\xc3\x84", "\xc3\x85", "\xc3\x86", "\xc3\x87",
+/* 0xc8 */ "\xc3\x88", "\xc3\x89", "\xc3\x8a", "\xc3\x8b",
+/* 0xcc */ "\xc3\x8c", "\xc3\x8d", "\xc3\x8e", "\xc3\x8f",
+/* 0xd0 */ "\xc4\x9e", "\xc3\x91", "\xc3\x92", "\xc3\x93",
+/* 0xd4 */ "\xc3\x94", "\xc3\x95", "\xc3\x96", "\xc3\x97",
+/* 0xd8 */ "\xc3\x98", "\xc3\x99", "\xc3\x9a", "\xc3\x9b",
+/* 0xdc */ "\xc3\x9c", "\xc4\xb0", "\xc5\x9e", "\xc3\x9f",
+/* 0xe0 */ "\xc3\xa0", "\xc3\xa1", "\xc3\xa2", "\xc3\xa3",
+/* 0xe4 */ "\xc3\xa4", "\xc3\xa5", "\xc3\xa6", "\xc3\xa7",
+/* 0xe8 */ "\xc3\xa8", "\xc3\xa9", "\xc3\xaa", "\xc3\xab",
+/* 0xec */ "\xc3\xac", "\xc3\xad", "\xc3\xae", "\xc3\xaf",
+/* 0xf0 */ "\xc4\x9f", "\xc3\xb1", "\xc3\xb2", "\xc3\xb3",
+/* 0xf4 */ "\xc3\xb4", "\xc3\xb5", "\xc3\xb6", "\xc3\xb7",
+/* 0xf8 */ "\xc3\xb8", "\xc3\xb9", "\xc3\xba", "\xc3\xbb",
+/* 0xfc */ "\xc3\xbc", "\xc4\xb1", "\xc5\x9f", "\xc3\xbf"
 },
 /*--------------------------------------------------------------------------*/
 /* iso 8859-6                                                               */
@@ -522,6 +523,64 @@ const char *utf8encodings[][256] = {
 /* 0xf8 */ REPLC_CHAR,     REPLC_CHAR,     REPLC_CHAR,     REPLC_CHAR,
 /* 0xfc */ REPLC_CHAR,     REPLC_CHAR,     REPLC_CHAR,     REPLC_CHAR
 },
+/*--------------------------------------------------------------------------*/
+/* iso 8859-5                                                               */
+/* based on: ftp://ftp.unicode.org/Public/MAPPINGS/ISO8859/8859-5.TXT       */
+/*--------------------------------------------------------------------------*/
+{
+/* 0x00 */ "ISO8859-5",    REPLC_CHAR,     REPLC_CHAR,     REPLC_CHAR,
+/* 0x04 */ REPLC_CHAR,     REPLC_CHAR,     REPLC_CHAR,     REPLC_CHAR,
+/* 0x08 */ REPLC_CHAR,     REPLC_CHAR,     REPLC_CHAR,     REPLC_CHAR,
+/* 0x0c */ REPLC_CHAR,     REPLC_CHAR,     REPLC_CHAR,     REPLC_CHAR,
+/* 0x10 */ REPLC_CHAR,     REPLC_CHAR,     REPLC_CHAR,     REPLC_CHAR,
+/* 0x14 */ REPLC_CHAR,     REPLC_CHAR,     REPLC_CHAR,     REPLC_CHAR,
+/* 0x18 */ REPLC_CHAR,     REPLC_CHAR,     REPLC_CHAR,     REPLC_CHAR,
+/* 0x1c */ REPLC_CHAR,     REPLC_CHAR,     REPLC_CHAR,     REPLC_CHAR,
+/* 0x20 */ " ",    "!",    "\"",   "#",    "$",    "%",    "&",    "'",
+/* 0x28 */ "(",    ")",    "*",    "+",    ",",    "-",    ".",    "/",
+/* 0x30 */ "0",    "1",    "2",    "3",    "4",    "5",    "6",    "7",
+/* 0x38 */ "8",    "9",    ":",    ";",    "<",    "=",    ">",    "?",
+/* 0x40 */ "@",    "A",    "B",    "C",    "D",    "E",    "F",    "G",
+/* 0x48 */ "H",    "I",    "J",    "K",    "L",    "M",    "N",    "O",
+/* 0x50 */ "P",    "Q",    "R",    "S",    "T",    "U",    "V",    "W",
+/* 0x58 */ "X",    "Y",    "Z",    "[",    "\\",   "]",    "^",    "_",
+/* 0x60 */ "`",    "a",    "b",    "c",    "d",    "e",    "f",    "g",
+/* 0x68 */ "h",    "i",    "j",    "k",    "l",    "m",    "n",    "o",
+/* 0x70 */ "p",    "q",    "r",    "s",    "t",    "u",    "v",    "w",
+/* 0x78 */ "x",    "y",    "z",    "{",    "|",    "}",    "~",    "\x7f",
+/* 0x80 */ "\xc2\x80",     "\xc2\x81",     "\xc2\x82",     "\xc2\x83",
+/* 0x84 */ "\xc2\x84",     "\xc2\x85",     "\xc2\x86",     "\xc2\x87",
+/* 0x88 */ "\xc2\x88",     "\xc2\x89",     "\xc2\x8a",     "\xc2\x8b",
+/* 0x8c */ "\xc2\x8c",     "\xc2\x8d",     "\xc2\x8e",     "\xc2\x8f",
+/* 0x90 */ "\xc2\x90",     "\xc2\x91",     "\xc2\x92",     "\xc2\x93",
+/* 0x94 */ "\xc2\x94",     "\xc2\x95",     "\xc2\x96",     "\xc2\x97",
+/* 0x98 */ "\xc2\x98",     "\xc2\x99",     "\xc2\x9a",     "\xc2\x9b",
+/* 0x9c */ "\xc2\x9c",     "\xc2\x9d",     "\xc2\x9e",     "\xc2\x9f",
+/* 0xa0 */ "\xc2\xa0",     "\xd0\x81",     "\xd0\x82",     "\xd0\x83",
+/* 0xa4 */ "\xd0\x84",     "\xd0\x85",     "\xd0\x86",     "\xd0\x87",
+/* 0xa8 */ "\xd0\x88",     "\xd0\x89",     "\xd0\x8a",     "\xd0\x8b",
+/* 0xac */ "\xd0\x8c",     "\xc2\xad",     "\xd0\x8e",     "\xd0\x8f",
+/* 0xb0 */ "\xd0\x90",     "\xd0\x91",     "\xd0\x92",     "\xd0\x93",
+/* 0xb4 */ "\xd0\x94",     "\xd0\x95",     "\xd0\x96",     "\xd0\x97",
+/* 0xb8 */ "\xd0\x98",     "\xd0\x99",     "\xd0\x9a",     "\xd0\x9b",
+/* 0xbc */ "\xd0\x9c",     "\xd0\x9d",     "\xd0\x9e",     "\xd0\x9f",
+/* 0xc0 */ "\xd0\xa0",     "\xd0\xa1",     "\xd0\xa2",     "\xd0\xa3",
+/* 0xc4 */ "\xd0\xa4",     "\xd0\xa5",     "\xd0\xa6",     "\xd0\xa7",
+/* 0xc8 */ "\xd0\xa8",     "\xd0\xa9",     "\xd0\xaa",     "\xd0\xab",
+/* 0xcc */ "\xd0\xac",     "\xd0\xad",     "\xd0\xae",     "\xd0\xaf",
+/* 0xd0 */ "\xd0\xb0",     "\xd0\xb1",     "\xd0\xb2",     "\xd0\xb3",
+/* 0xd4 */ "\xd0\xb4",     "\xd0\xb5",     "\xd0\xb6",     "\xd0\xb7",
+/* 0xd8 */ "\xd0\xb8",     "\xd0\xb9",     "\xd0\xba",     "\xd0\xbb",
+/* 0xdc */ "\xd0\xbc",     "\xd0\xbd",     "\xd0\xbe",     "\xd0\xbf",
+/* 0xe0 */ "\xd1\x80",     "\xd1\x81",     "\xd1\x82",     "\xd1\x83",
+/* 0xe4 */ "\xd1\x84",     "\xd1\x85",     "\xd1\x86",     "\xd1\x87",
+/* 0xe8 */ "\xd1\x88",     "\xd1\x89",     "\xd1\x8a",     "\xd1\x8b",
+/* 0xec */ "\xd1\x8c",     "\xd1\x8d",     "\xd1\x8e",     "\xd1\x8f",
+/* 0xf0 */ "\xe2\x84\x96", "\xd1\x91",     "\xd1\x92",     "\xd1\x93",
+/* 0xf4 */ "\xd1\x94",     "\xd1\x95",     "\xd1\x96",     "\xd1\x97",
+/* 0xf8 */ "\xd1\x98",     "\xd1\x99",     "\xd1\x9a",     "\xd1\x9b",
+/* 0xfc */ "\xd1\x9c",     "\xc2\xa7",     "\xd1\x9e",     "\xd1\x9f"
+},
 
 /*--------------------------------------------------------------------------*/
 /* Closing line should be NULL                                              */
@@ -530,3 +589,36 @@ const char *utf8encodings[][256] = {
 
 };
 
+/*----------------------------------------------------------------------*/
+/* Routine to search for a UTF-8 code in the tables and return the	*/
+/* associated 8-bit code (reverse lookup).				*/
+/*									*/
+/* Note that this routine does not check whether or not the encoding	*/
+/* scheme containing the UTF-8 character code is the encoding		*/
+/* currently in effect in a text string.				*/
+/*----------------------------------------------------------------------*/
+
+int utf8_reverse_lookup(char *utf8string)
+{
+    int i, j;
+    char *s1, *s2;
+
+    for (i = 0; ; i++) {
+	if (utf8encodings[i][0] == NULL) break;
+	for (j = 0; j < 256; j++) {
+	    s1 = (char *)utf8encodings[i][j];
+	    s2 = utf8string;
+	    while (*s1 == *s2) {
+		if (*s1 == '\0')
+		    return j;
+		s1++;
+		s2++;
+	    }
+	    /* NOTE: Xutf8LookupString() results in strings longer than	*/
+	    /* expected for the UTF-8 code.  Not sure what they are, 	*/
+	    /* but the initial part matches the expected code.		*/
+	    if ((*s1 == '\0') && (s2 > (utf8string + 1))) return j;
+	}
+    }
+    return -1;
+}
