@@ -26,7 +26,7 @@
 #define W32DEBUG(x)
 #endif
 
-extern Clientdata areastruct;
+extern XCWindowData *areawin;
 extern Globaldata xobjs;
 extern char _STR2[250];
 extern Pixmap   STIPPLE[STIPPLES];  /* Polygon fill-style stipple patterns */
@@ -42,7 +42,6 @@ static char STIPDATA[STIPPLES][4] = {
 };
 extern xcWidget top, message2, message3;
 extern ApplicationData appdata;
-extern int* appcolors;
 extern int number_colors;
 extern colorindex *colorlist;
 extern menustruct TopButtons[];
@@ -771,6 +770,11 @@ GC WinCreateGC(HWND win, int mask, XGCValues *values)
 	return gc;
 }
 
+void WinFreeGC(GC gc)
+{
+	free(gc);
+}
+
 void WinSetDashes(GC gc, int offset, char *dash, int n)
 {
 	if (gc->line_dash) {
@@ -1064,7 +1068,7 @@ void popupprompt(Widget button, char *request, char *current, void (*function)()
 
 		data.request = request;
 		data.current = current;
-		if (DialogBoxParam(GetModuleHandle(NULL), MAKEINTRESOURCE(IDD_INPUTDIALOG), areastruct.areawin, InputDlgProc, (LPARAM)&data))
+		if (DialogBoxParam(GetModuleHandle(NULL), MAKEINTRESOURCE(IDD_INPUTDIALOG), areawin->window, InputDlgProc, (LPARAM)&data))
 			(*function)(button, (datastruct != NULL ? datastruct->dataptr : NULL));
 	} else if (filter != NULL) {
 		OPENFILENAME ofn;
@@ -1073,7 +1077,7 @@ void popupprompt(Widget button, char *request, char *current, void (*function)()
 
 		ZeroMemory(&ofn, sizeof(ofn));
 		ofn.lStructSize = sizeof(ofn);
-		ofn.hwndOwner = areastruct.areawin;
+		ofn.hwndOwner = areawin->window;
 		if (*filter) {
 			_snprintf(filterspec, 1024, "Enable Filter (*%s)%c*%s%cDisable Filter (*.*)%c*.*%c%c%c",
 				       	filter, 0, filter, 0, 0, 0, 0, 0);
@@ -1090,7 +1094,7 @@ void popupprompt(Widget button, char *request, char *current, void (*function)()
 			(*function)(button, datastruct->dataptr);
 		}
 	} else {
-		if (MessageBox(areastruct.areawin, request, "XCircuit", MB_YESNO|MB_ICONQUESTION) == IDYES)
+		if (MessageBox(areawin->window, request, "XCircuit", MB_YESNO|MB_ICONQUESTION) == IDYES)
 			(*function)(button, datastruct->dataptr);
 	}
 
@@ -1389,8 +1393,37 @@ LRESULT CALLBACK XcTopWindowProc(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lPar
 			quitcheck(NULL, NULL, NULL);
 			return 0;
 		case WM_ACTIVATE:
-			if (wParam != 0)
-				SetFocus(areastruct.areawin);
+			if (wParam != 0) {
+				XCWindowData *w;
+
+				for (w=xobjs.windowlist; w!=NULL; w=w->next)
+					if (GetAncestor(w->window, GA_ROOT) == hwnd)
+						break;
+				if (w != NULL && areawin != w) {
+					areawin = w;
+					top = get_widget(GetAncestor(areawin->window, GA_ROOT));
+					topwin = top->handle;
+					toolBar = get_widget(GetDlgItem(topwin, TOOLBAR_ID));
+					statusBar = GetDlgItem(topwin, STATUSBAR_ID);
+					{
+						MENUITEMINFO mi_info;
+						HMENU hMenu = GetMenu(hwnd);
+						int i;
+
+						ZeroMemory(&mi_info, sizeof(mi_info));
+						mi_info.cbSize = sizeof(mi_info);
+						for (i=0; i<MaxMenuWidgets; i++) {
+							mi_info.fMask = MIIM_DATA;
+							mi_info.dwItemData = (LONG)NULL;
+							if (GetMenuItemInfo(hMenu, 100+i, FALSE, &mi_info))
+								menuwidgets[i] = (Widget)mi_info.dwItemData;
+							else
+								printf("menu not found: %d\n", i);
+						}
+					}
+				}
+				SetFocus(areawin->window);
+			}
 			return 0;
 		case WM_SIZE:
 			{
@@ -1406,9 +1439,9 @@ LRESULT CALLBACK XcTopWindowProc(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lPar
 				GetWindowRect(statusBar, &sr);
 				sh = sr.bottom-sr.top;
 
-				SetWindowPos(areastruct.area->handle, HWND_TOP, SBARSIZE, th, width-SBARSIZE, height-sh-th-SBARSIZE, 0);
-				SetWindowPos(areastruct.scrollbarh->handle, HWND_TOP, SBARSIZE, height-sh-SBARSIZE, width-SBARSIZE, SBARSIZE, 0);
-				SetWindowPos(areastruct.scrollbarv->handle, HWND_TOP, 0, th, SBARSIZE, height-sh-th-SBARSIZE, 0);
+				SetWindowPos(areawin->area->handle, HWND_TOP, SBARSIZE, th, width-SBARSIZE, height-sh-th-SBARSIZE, 0);
+				SetWindowPos(areawin->scrollbarh->handle, HWND_TOP, SBARSIZE, height-sh-SBARSIZE, width-SBARSIZE, SBARSIZE, 0);
+				SetWindowPos(areawin->scrollbarv->handle, HWND_TOP, 0, th, SBARSIZE, height-sh-th-SBARSIZE, 0);
 				SetWindowPos(corner, HWND_TOP, 0, height-sh-SBARSIZE, 0, 0, SWP_NOSIZE);
 				SetWindowPos(statusBar, HWND_TOP, 0, height-sh, width, sh, 0);
 				InvalidateRect(statusBar, NULL, FALSE);
@@ -1467,7 +1500,7 @@ void button_event(Widget win, int type, int button, short x, short y)
 		      (GetKeyState(VK_SHIFT) & 0x8000 ? ShiftMask : 0) |
 		      (GetKeyState(VK_MENU) & 0x8000 ? Mod1Mask : 0);
 
-	if (win == areastruct.scrollbarh || win == areastruct.scrollbarv)
+	if (win == areawin->scrollbarh || win == areawin->scrollbarv)
 		if (type == ButtonPress)
 			SetCapture(win->handle);
 		else if (type == ButtonRelease)
@@ -1815,7 +1848,7 @@ static MenuItem insert_win_menuitem(Menu menu, MENUITEMINFO* mi_info, menustruct
 	} else if (!(mi_info->fMask & MIIM_FTYPE && mi_info->fType == MFT_SEPARATOR)){
 	}
 	if (ms != NULL) {
-		if (ms->func != NULL)
+		if (ms->func != NULL && ms->func != DoNothing)
 			WinAddCallback((Widget)item, XtNselect, ms->func, ms->passeddata);
 		item->name = strdup(ms->name);
 	}
@@ -1895,6 +1928,36 @@ static char* color_string(int c)
 	return buf;
 }
 
+static void makesubmenu(Menu menu, menustruct *items, int n);
+static void make_color_submenu(Menu menu, menustruct *items, int n)
+{
+	if (dpy == NULL)
+		makesubmenu(menu, items, n);
+	else {
+		int i;
+		MENUITEMINFO mi_info;
+		MenuItem item;
+
+		makesubmenu(menu, items, 3);
+		menuID += (n-3);
+		for (i=0; i<number_colors; i++) {
+			int color = colorlist[i].color.pixel;
+			HBITMAP hBitmap = create_color_icon(color, MENUICON_WIDTH, MENUICON_HEIGHT);
+			ZeroMemory(&mi_info, sizeof(mi_info));
+			mi_info.cbSize = sizeof(mi_info);
+			mi_info.fMask = MIIM_BITMAP | MIIM_STRING;
+			mi_info.hbmpItem = hBitmap;
+			mi_info.dwTypeData = color_string(color);
+			mi_info.dwItemData = color;
+		
+			item = insert_win_menuitem(menu, &mi_info, NULL, -1);
+			item->name = strdup(mi_info.dwTypeData);
+			WinAddCallback((Widget)item, XtNselect, (XtCallbackProc)setcolor, NULL);
+		}
+	}
+		
+}
+
 static void makesubmenu(Menu menu, menustruct *items, int n)
 {
 	int i;
@@ -1937,13 +2000,16 @@ static void makesubmenu(Menu menu, menustruct *items, int n)
 			}
 		} else {
 			Menu popup = create_win_menu(CreatePopupMenu());
-			makesubmenu(popup, items[i].submenu, items[i].size);
+			if (strncmp(items[i].name, "Color", 5) == 0)
+				make_color_submenu(popup, items[i].submenu, items[i].size);
+			else
+				makesubmenu(popup, items[i].submenu, items[i].size);
 			mi_info.fMask = MIIM_SUBMENU | MIIM_STRING;
 			mi_info.hSubMenu = popup->handle;
 			mi_info.dwTypeData = items[i].name;
 		}
 		mitem = insert_win_menuitem(menu, &mi_info, &items[i], -1);
-		if (is_color != -1)
+		if (is_color != -1 && dpy == NULL)
 			addtocolorlist((Widget)mitem, is_color);
 	}
 }
@@ -1954,6 +2020,7 @@ static HMENU create_menus()
 	MENUITEMINFO mi_info;
 	int i;
 
+	menuID = 100;
 	menu = create_win_menu(CreateMenu());
 	for (i=0; i<maxbuttons; i++) {
 		ZeroMemory(&mi_info, sizeof(mi_info));
@@ -1969,10 +2036,6 @@ static HMENU create_menus()
 			mi_info.hSubMenu = popup->handle;
 			mi_info.dwTypeData = TopButtons[i].name;
 		}
-		if (!strcmp(TopButtons[i].name, "Netlist")) {
-			if (!areastruct.schemon)
-				/* should make menu invisible*/;
-		}
 		insert_win_menuitem(menu, &mi_info, &TopButtons[i], -1);
 	}
 
@@ -2169,12 +2232,13 @@ static void register_win32_classes()
 	*/
 }
 
-void GUI_init(int argc, char *argv[])
+XCWindowData* GUI_init(int argc, char *argv[])
 {
 	int i;
 	XGCValues values;
 	Arg wargs[2];
 	RECT clientRect = { 0, 0, 0, 0 };
+	XCWindowData *newwin;
 
 #if 0 && defined(USE_WIN32_COM)
 	for (i=0; i<argc; i++)
@@ -2184,55 +2248,57 @@ void GUI_init(int argc, char *argv[])
 			COM_register(0);
 #endif
 
-	register_win32_classes();
+	if (dpy == NULL) {
+		register_win32_classes();
 
-	appdata.globalcolor = WinNamedColor("Orange2");
-	appdata.localcolor = WinNamedColor("Red");
-	appdata.infocolor = WinNamedColor("SeaGreen");
-	appdata.ratsnestcolor = WinNamedColor("Tan4");
-	appdata.bboxpix = WinNamedColor("greenyellow");
-	appdata.fg = WinNamedColor("Black");
-	appdata.bg = WinNamedColor("White");
-	appdata.gridpix = WinNamedColor("Gray95");
-	appdata.snappix = WinNamedColor("Red");
-	appdata.selectpix = WinNamedColor("Gold3");
-	appdata.querypix = WinNamedColor("Turquoise");
-	appdata.filterpix = WinNamedColor("SteelBlue3");
-	appdata.axespix = WinNamedColor("Antique White");
-	appdata.buttonpix = WinNamedColor("Gray85");
-	appdata.auxpix = WinNamedColor("Green3");
-	appdata.barpix = WinNamedColor("Tan");
-	appdata.parampix = WinNamedColor("Plum3");
-	appdata.fg2 = WinNamedColor("White");
-	appdata.bg2 = WinNamedColor("DarkSlateGray");
-	appdata.gridpix2 = WinNamedColor("Gray40");
-	appdata.snappix2 = WinNamedColor("Red");
-	appdata.selectpix2 = WinNamedColor("Gold");
-	appdata.querypix2 = WinNamedColor("Turquoise");
-	appdata.filterpix2 = WinNamedColor("SteelBlue1");
-	appdata.axespix2 = WinNamedColor("NavajoWhite4");
-	appdata.buttonpix2 = WinNamedColor("Gray50");
-	appdata.auxpix2 = WinNamedColor("Green");
-	appdata.barpix2 = WinNamedColor("Tan");
-	appdata.parampix2 = WinNamedColor("Plum3");
-	appdata.width = 950;
-	appdata.height = 760;
-	appdata.timeout = 10;
-	appdata.xcfont = create_font_struct(GetStockObject(DEFAULT_GUI_FONT));
-	appdata.helpfont = create_font_struct(GetStockObject(DEFAULT_GUI_FONT));
-	appdata.filefont = create_font_struct(GetStockObject(DEFAULT_GUI_FONT));
-	appdata.textfont = create_font_struct(GetStockObject(DEFAULT_GUI_FONT));
-	appdata.titlefont = create_font_struct(GetStockObject(DEFAULT_GUI_FONT));
+		appdata.globalcolor = WinNamedColor("Orange2");
+		appdata.localcolor = WinNamedColor("Red");
+		appdata.infocolor = WinNamedColor("SeaGreen");
+		appdata.ratsnestcolor = WinNamedColor("Tan4");
+		appdata.bboxpix = WinNamedColor("greenyellow");
+		appdata.fixedbboxpix = WinNamedColor("Pink");
+		appdata.clipcolor = WinNamedColor("powderblue");
+		appdata.fg = WinNamedColor("Black");
+		appdata.bg = WinNamedColor("White");
+		appdata.gridpix = WinNamedColor("Gray95");
+		appdata.snappix = WinNamedColor("Red");
+		appdata.selectpix = WinNamedColor("Gold3");
+		appdata.querypix = WinNamedColor("Turquoise");
+		appdata.filterpix = WinNamedColor("SteelBlue3");
+		appdata.axespix = WinNamedColor("Antique White");
+		appdata.buttonpix = WinNamedColor("Gray85");
+		appdata.auxpix = WinNamedColor("Green3");
+		appdata.barpix = WinNamedColor("Tan");
+		appdata.parampix = WinNamedColor("Plum3");
+		appdata.fg2 = WinNamedColor("White");
+		appdata.bg2 = WinNamedColor("DarkSlateGray");
+		appdata.gridpix2 = WinNamedColor("Gray40");
+		appdata.snappix2 = WinNamedColor("Red");
+		appdata.selectpix2 = WinNamedColor("Gold");
+		appdata.querypix2 = WinNamedColor("Turquoise");
+		appdata.filterpix2 = WinNamedColor("SteelBlue1");
+		appdata.axespix2 = WinNamedColor("NavajoWhite4");
+		appdata.buttonpix2 = WinNamedColor("Gray50");
+		appdata.auxpix2 = WinNamedColor("Green");
+		appdata.barpix2 = WinNamedColor("Tan");
+		appdata.parampix2 = WinNamedColor("Plum3");
+		appdata.width = 950;
+		appdata.height = 760;
+		appdata.timeout = 10;
+		appdata.xcfont = create_font_struct(GetStockObject(DEFAULT_GUI_FONT));
+		appdata.helpfont = create_font_struct(GetStockObject(DEFAULT_GUI_FONT));
+		appdata.filefont = create_font_struct(GetStockObject(DEFAULT_GUI_FONT));
+		appdata.textfont = create_font_struct(GetStockObject(DEFAULT_GUI_FONT));
+		appdata.titlefont = create_font_struct(GetStockObject(DEFAULT_GUI_FONT));
 
-	for (i=0; i<STIPPLES; i++) {
-		STIPPLE[i] = WinCreateBitmapFromData(NULL, STIPDATA[i], 4, 4);
+		for (i=0; i<STIPPLES; i++) {
+			STIPPLE[i] = WinCreateBitmapFromData(NULL, STIPDATA[i], 4, 4);
+		}
+
+		number_colors = NUMBER_OF_COLORS;
+		colorlist = (colorindex *)malloc(NUMBER_OF_COLORS * sizeof(colorindex));
 	}
 
-	number_colors = 0;
-	colorlist = (colorindex *)malloc(sizeof(colorindex));
-	appcolors = (int *) malloc(NUMBER_OF_COLORS * sizeof(int));
-
-
 	clientRect.right = appdata.width+SBARSIZE;
 	clientRect.bottom = appdata.height+SBARSIZE;
 	AdjustWindowRect(&clientRect, WS_TILEDWINDOW, TRUE);
@@ -2243,53 +2309,54 @@ void GUI_init(int argc, char *argv[])
 	topwin = top->handle;
 
      	dpy = XtDisplay(top);
+	newwin = create_new_window();
 
-	areastruct.scrollbarv = create_widget(CreateWindow("XcScrollBar", "SBV", WS_VISIBLE|WS_CHILD,
+	newwin->scrollbarv = create_widget(CreateWindow("XcScrollBar", "SBV", WS_VISIBLE|WS_CHILD,
 				0, 0, SBARSIZE, appdata.height-SBARSIZE, top->handle, 0, NULL, NULL), "SBV");
-	areastruct.scrollbarh = create_widget(CreateWindow("XcScrollBar", "SBH", WS_VISIBLE|WS_CHILD,
+	newwin->scrollbarh = create_widget(CreateWindow("XcScrollBar", "SBH", WS_VISIBLE|WS_CHILD,
 				SBARSIZE, appdata.height-SBARSIZE, appdata.width-SBARSIZE, SBARSIZE, top->handle, 0, NULL, NULL), "SBH");
-	areastruct.area = create_widget(CreateWindow("XcWidget", "Area", WS_VISIBLE|WS_CHILD,
+	newwin->area = create_widget(CreateWindow("XcWidget", "Area", WS_VISIBLE|WS_CHILD,
 				SBARSIZE, 0, appdata.width, appdata.height, top->handle, 0, NULL, NULL), "Area");
-	areastruct.areawin = areastruct.area->handle;
+	newwin->window = newwin->area->handle;
 	corner = CreateWindow("BUTTON", "", WS_CHILD|WS_VISIBLE|BS_PUSHBUTTON|BS_FLAT, 0, appdata.height-SBARSIZE, SBARSIZE, SBARSIZE, top->handle, NULL, NULL, NULL);
 
 	create_statusbar();
 	create_toolbar();
 
-     	XtAddCallback(areastruct.area, XtNexpose, (XtCallbackProc)drawarea, NULL);
-     	XtAddCallback(areastruct.area, XtNresize, (XtCallbackProc)resizearea, NULL);
+     	XtAddCallback(newwin->area, XtNexpose, (XtCallbackProc)drawarea, NULL);
+     	XtAddCallback(newwin->area, XtNresize, (XtCallbackProc)resizearea, NULL);
 
-     	XtAddCallback(areastruct.area, XtNselect, (XtCallbackProc)buttonhandler, NULL);
-     	XtAddCallback(areastruct.area, XtNrelease, (XtCallbackProc)buttonhandler, NULL);
-     	XtAddCallback(areastruct.area, XtNkeyDown, (XtCallbackProc)keyhandler, NULL);
-     	XtAddCallback(areastruct.area, XtNkeyUp, (XtCallbackProc)keyhandler, NULL);
+     	XtAddCallback(newwin->area, XtNselect, (XtCallbackProc)buttonhandler, NULL);
+     	XtAddCallback(newwin->area, XtNrelease, (XtCallbackProc)buttonhandler, NULL);
+     	XtAddCallback(newwin->area, XtNkeyDown, (XtCallbackProc)keyhandler, NULL);
+     	XtAddCallback(newwin->area, XtNkeyUp, (XtCallbackProc)keyhandler, NULL);
 
-	XtAddEventHandler(areastruct.area, Button1MotionMask | Button2MotionMask,
+	XtAddEventHandler(newwin->area, Button1MotionMask | Button2MotionMask,
 			False, (XtEventHandler)xlib_drag, NULL);
 
-     	XtAddEventHandler(areastruct.scrollbarh, ButtonMotionMask, False,
+     	XtAddEventHandler(newwin->scrollbarh, ButtonMotionMask, False,
 			(XtEventHandler)panhbar, NULL);
-     	XtAddEventHandler(areastruct.scrollbarv, ButtonMotionMask, False,
+     	XtAddEventHandler(newwin->scrollbarv, ButtonMotionMask, False,
 			(XtEventHandler)panvbar, NULL);
 
-     	XtAddCallback(areastruct.scrollbarh, XtNrelease, (XtCallbackProc)endhbar, NULL);
-     	XtAddCallback(areastruct.scrollbarv, XtNrelease, (XtCallbackProc)endvbar, NULL);
+     	XtAddCallback(newwin->scrollbarh, XtNrelease, (XtCallbackProc)endhbar, NULL);
+     	XtAddCallback(newwin->scrollbarv, XtNrelease, (XtCallbackProc)endvbar, NULL);
 
-	XtAddCallback(areastruct.scrollbarh, XtNexpose, (XtCallbackProc)drawhbar, NULL);
-     	XtAddCallback(areastruct.scrollbarv, XtNexpose, (XtCallbackProc)drawvbar, NULL);
-     	XtAddCallback(areastruct.scrollbarh, XtNresize, (XtCallbackProc)drawhbar, NULL);
-     	XtAddCallback(areastruct.scrollbarv, XtNresize, (XtCallbackProc)drawvbar, NULL);
+	XtAddCallback(newwin->scrollbarh, XtNexpose, (XtCallbackProc)drawhbar, NULL);
+     	XtAddCallback(newwin->scrollbarv, XtNexpose, (XtCallbackProc)drawvbar, NULL);
+     	XtAddCallback(newwin->scrollbarh, XtNresize, (XtCallbackProc)drawhbar, NULL);
+     	XtAddCallback(newwin->scrollbarv, XtNresize, (XtCallbackProc)drawvbar, NULL);
 	
      	values.foreground = RGB(0, 0, 0);
      	values.background = RGB(255, 255, 255);
      	values.font = appdata.xcfont->fid;
 
-     	areastruct.gc = XCreateGC(dpy, areastruct.areawin,
+     	newwin->gc = XCreateGC(dpy, newwin->window,
 			GCForeground | GCBackground | GCFont, &values);
 
-     	XtSetArg(wargs[0], XtNwidth, &areastruct.width);
-     	XtSetArg(wargs[1], XtNheight, &areastruct.height);
-    	XtGetValues(areastruct.area, wargs, 2);
+     	XtSetArg(wargs[0], XtNwidth, &newwin->width);
+     	XtSetArg(wargs[1], XtNheight, &newwin->height);
+    	XtGetValues(newwin->area, wargs, 2);
 
 	SendMessage(((ToolItem)WireToolButton)->toolbar->handle, TB_CHECKBUTTON, ((ToolItem)WireToolButton)->ID, MAKELONG(TRUE, 0));
 
@@ -2297,6 +2364,8 @@ void GUI_init(int argc, char *argv[])
 	if (!COM_initialize())
 		printf("Failed to initialize COM interface\n");
 #endif
+
+	return newwin;
 }
 
 void WinAddEventHandler(Widget win, int event, void(*proc)(), void *data)
@@ -2663,6 +2732,18 @@ int WinNamedColor(const char *cname)
 	return -1;
 }
 
+int WinLookupColor(const char *cname, XColor *color)
+{
+	int cval = WinNamedColor(cname);
+	if (cval == -1)
+		return 0;
+	else {
+		color->pixel = cval;
+		WinQueryColors(color, 1);
+		return 1;
+	}
+}
+
 char *WinColorName(int c)
 {
 	int red = GetRValue(c), green = GetGValue(c), blue = GetBValue(c);
@@ -2696,7 +2777,7 @@ void WinDebug(char *c)
 	W32DEBUG(("%s", c));
 }
 
-void WinLookupString(XEvent *event, KeySym *key)
+void WinLookupString(XKeyEvent *event, KeySym *key)
 {
 	XKeyEvent *kevent = (XKeyEvent*)event;
 	int vk = kevent->keycode & 0xff;
@@ -2773,7 +2854,7 @@ void overdrawpixmap(Widget button)
 
 void starthelp(xcWidget button, caddr_t clientdata, caddr_t calldata)
 {
-	DialogBoxParam(GetModuleHandle(NULL), MAKEINTRESOURCE(IDD_HELPDLG), areastruct.areawin, HelpDlgProc, (LPARAM)NULL);
+	DialogBoxParam(GetModuleHandle(NULL), MAKEINTRESOURCE(IDD_HELPDLG), areawin->window, HelpDlgProc, (LPARAM)NULL);
 }
 
 /*
@@ -2950,14 +3031,14 @@ LRESULT CALLBACK OutputDlgProc(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam
 				SendDlgItemMessage(hwnd, IDC_MODE, CB_ADDSTRING, 0, (LPARAM)"Embedded (EPS)");
 				SendDlgItemMessage(hwnd, IDC_MODE, CB_ADDSTRING, 0, (LPARAM)"Full page");
 
-				curpage = xobjs.pagelist[areastruct.page];
+				curpage = xobjs.pagelist[areawin->page];
 				entertext = (Widget*)malloc(sizeof(Widget)*MAXPROPS);
 				memset(okstruct, 0, sizeof(propstruct)*MAXPROPS);
 
 				sprintf(edit[0], "%s", curpage->filename);
 				sprintf(edit[1], "%s", topobject->name);
-				calcbbox(areastruct.topinstance);
-				if (curpage->pmode & 2) autoscale(areastruct.page);
+				calcbbox(areawin->topinstance);
+				if (curpage->pmode & 2) autoscale(areawin->page);
 				writescalevalues(edit[2], edit[3], edit[4]);
 				sprintf(edit[5], "%s", (curpage->orient == 0) ? "Portrait" : "Landscape");
 				sprintf(edit[6], "%s", (curpage->pmode & 1) ? "Full page" : "Embedded (EPS)");
@@ -2972,7 +3053,7 @@ LRESULT CALLBACK OutputDlgProc(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam
 				create_widget(GetDlgItem(hwnd, IDOK), "Write File");
 				create_widget(GetDlgItem(hwnd, IDCANCEL), "Close");
 				
-				sprintf(request, "PostScript output properties (Page %d):", areastruct.page + 1);
+				sprintf(request, "PostScript output properties (Page %d):", areawin->page + 1);
 				sprintf(statics[0], "Filename:");
 				sprintf(statics[1], "Page label:");
 				sprintf(statics[2], "Scale:");
@@ -3029,7 +3110,7 @@ LRESULT CALLBACK OutputDlgProc(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam
 					}
 				}
 
-				sprintf(request, "%d Pages", pagelinks(areastruct.page));
+				sprintf(request, "%d Pages", pagelinks(areawin->page));
 				win = create_widget(GetDlgItem(hwnd, IDC_PAGENUM), "LToggle");
 				SetWindowText(win->handle, request);
 				CheckDlgButton(hwnd, IDC_PAGENUM, BST_CHECKED);
@@ -3067,7 +3148,7 @@ LRESULT CALLBACK OutputDlgProc(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam
 					XtManageChild(fpokstruct.buttonw);
 				}
 
-				if (pagelinks(areastruct.page) > 1)
+				if (pagelinks(areawin->page) > 1)
 					XtManageChild(get_widget(GetDlgItem(hwnd, IDC_PAGENUM)));
 
 				SetFocus(entertext[0]->handle);
@@ -3269,3 +3350,16 @@ void win32_comdotnet()
 }
 
 #endif
+
+void win32_new_window(Widget w, void *clientData, void *callData)
+{
+	XCWindowData *newwin = GUI_init(0, NULL);
+
+	newwin->page = areawin->page;
+	newwin->vscale = areawin->vscale;
+	newwin->pcorner = areawin->pcorner;
+	newwin->topinstance = areawin->topinstance;
+
+	areawin = newwin;
+	ShowWindow(top->handle, SW_SHOW);
+}
