@@ -23,6 +23,7 @@ extern int xctcl_standardaction();
 extern int xctcl_action();
 extern int xctcl_refresh();
 extern int xctcl_library();
+extern int xctcl_tech();
 extern int xctcl_font();
 extern int xctcl_cursor();
 extern int xctcl_bind();
@@ -32,7 +33,6 @@ extern int xctcl_dofill();
 extern int xctcl_doborder();
 extern int xctcl_promptquit();
 extern int xctcl_quit();
-extern int xctcl_promptsavelib();
 extern int xctcl_promptsavepage();
 extern int xctcl_eventmode();
 extern int xctcl_delete();
@@ -51,6 +51,7 @@ extern int xctcl_flip();
 extern int xctcl_config();
 extern int xctcl_page();
 extern int xctcl_spice();
+extern int xctcl_svg();
 extern int xctcl_zoom();
 extern int xctcl_pan();
 extern int xctcl_element();
@@ -81,6 +82,7 @@ static cmdstruct xc_commands[] =
    {"tag", (void *)xctcl_tag},
    {"refresh", (void *)xctcl_refresh},
    {"library", (void *)xctcl_library},
+   {"technology", (void *)xctcl_tech},
    {"loadfont", (void *)xctcl_font},
    {"cursor", (void *)xctcl_cursor},
    {"bindkey", (void *)xctcl_bind},
@@ -90,7 +92,6 @@ static cmdstruct xc_commands[] =
    {"border", (void *)xctcl_doborder},
    {"quit", (void *)xctcl_promptquit},
    {"quitnocheck", (void *)xctcl_quit},
-   {"promptchecksavelib", (void *)xctcl_promptsavelib},
    {"promptsavepage", (void *)xctcl_promptsavepage},
    {"eventmode", (void *)xctcl_eventmode},
    {"delete", (void *)xctcl_delete},
@@ -124,6 +125,7 @@ static cmdstruct xc_commands[] =
    {"symbol", (void *)xctcl_symschem},
    {"schematic", (void *)xctcl_symschem},
    {"spice", (void *)xctcl_spice},
+   {"svg", (void *)xctcl_svg},
    {"", NULL}  /* sentinel */
 };
 
@@ -142,7 +144,7 @@ Xcircuit_Init(Tcl_Interp *interp)
    char command[256];
    int cmdidx;
    Tk_Window tktop;
-   char *tmp_s;
+   char *tmp_s, *tmp_l;
    char *cadhome;
    char version_string[20];
 
@@ -154,8 +156,11 @@ Xcircuit_Init(Tcl_Interp *interp)
 
    if (Tcl_InitStubs(interp, "8.1", 0) == NULL) return TCL_ERROR;
    
-   tmp_s = getenv("XCIRCUIT_LIB_DIR");
-   if (tmp_s == NULL) tmp_s = BUILTINS_DIR;
+   tmp_s = getenv("XCIRCUIT_SRC_DIR");
+   if (tmp_s == NULL) tmp_s = SCRIPTS_DIR;
+
+   tmp_l = getenv("XCIRCUIT_LIB_DIR");
+   if (tmp_l == NULL) tmp_l = BUILTINS_DIR;
  
    strcpy(command, "xcircuit::");
 
@@ -173,7 +178,7 @@ Xcircuit_Init(Tcl_Interp *interp)
    }
 
    /* Command which creates a "simple" window (this is a top-	*/
-   /* level command, not one in the xcircuit namespace,	which	*/
+   /* level command, not one in the xcircuit namespace which	*/
    /* is why I treat it separately from the other commands).	*/
 
    Tcl_CreateObjCommand(interp, "simple",
@@ -187,12 +192,13 @@ Xcircuit_Init(Tcl_Interp *interp)
       Tcl_Eval(interp, command);
    }
    
-   if (strcmp(tmp_s, BUILTINS_DIR))
-      Tcl_Eval(interp, "lappend auto_path " BUILTINS_DIR );
+   if (strcmp(tmp_s, SCRIPTS_DIR))
+      Tcl_Eval(interp, "lappend auto_path " SCRIPTS_DIR );
 
-   /* Set $XCIRCUIT_LIB_DIR as a Tcl variable */
+   /* Set $XCIRCUIT_SRC_DIR and $XCIRCUIT_LIB_DIR as Tcl variables */
 
-   Tcl_SetVar(interp, "XCIRCUIT_LIB_DIR", tmp_s, TCL_GLOBAL_ONLY);
+   Tcl_SetVar(interp, "XCIRCUIT_SRC_DIR", tmp_s, TCL_GLOBAL_ONLY);
+   Tcl_SetVar(interp, "XCIRCUIT_LIB_DIR", tmp_l, TCL_GLOBAL_ONLY);
 
    /* Set $CAD_ROOT as a Tcl variable */
 
@@ -202,10 +208,10 @@ Xcircuit_Init(Tcl_Interp *interp)
 
    /* Set $XCIRCUIT_VERSION and $XCIRCUIT_REVISION as Tcl variables */
 
-   sprintf(version_string, "%d", PROG_REVISION);
+   sprintf(version_string, "%s", PROG_REVISION);
    Tcl_SetVar(interp, "XCIRCUIT_REVISION", version_string, TCL_GLOBAL_ONLY);
 
-   sprintf(version_string, "%g", PROG_VERSION);
+   sprintf(version_string, "%s", PROG_VERSION);
    Tcl_SetVar(interp, "XCIRCUIT_VERSION", version_string, TCL_GLOBAL_ONLY);
 
 #ifdef ASG
